% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LISA.R
\name{lisa}
\alias{lisa}
\title{Generate local indicators of spatial association}
\usage{
lisa(
  cells,
  Rs = NULL,
  BPPARAM = BiocParallel::SerialParam(),
  window = "square",
  window.length = NULL,
  whichParallel = "imageID"
)
}
\arguments{
\item{cells}{A SegmentedCells or data frame that contains at least the 
variables x and y, giving the  coordinates of each cell, and cellType.}

\item{Rs}{A vector of the radii that the measures of association should be calculated.}

\item{BPPARAM}{A BiocParallelParam object.}

\item{window}{Should the window around the regions be 'square', 'convex' or 'concave'.}

\item{window.length}{A tuning parameter for controlling the level of concavity 
when estimating concave windows.}

\item{whichParallel}{Should the function use parallization on the imageID or 
the cellType.}
}
\value{
A matrix of LISA curves
}
\description{
Generate local indicators of spatial association
}
\examples{
# Read in data as a SegmentedCells objects
isletFile <- system.file("extdata","isletCells.txt.gz", package = "spicyR")
cells <- read.table(isletFile, header=TRUE)
cellExp <- SegmentedCells(cells, cellProfiler = TRUE)

# Cluster cell types
markers <- cellMarks(cellExp)
kM <- kmeans(markers,8)
cellType(cellExp) <- paste('cluster',kM$cluster, sep = '')

# Generate LISA
lisaCurves <- lisa(cellExp)

# Cluster the LISA curves
kM <- kmeans(lisaCurves,2)
region(cellExp) <- paste('region',kM$cluster,sep = '_')

}
